Runtime

Struct Runtime 

pub struct Runtime<'a, S>
where S: Subscribable,
{ /* private fields */ }
The Retina runtime.

The runtime initializes the DPDK environment abstraction layer, creates memory pools, launches the packet processing cores, and manages logging and display output.

Implementations

Source

impl<'a, S> Runtime<'a, S>
where S: Subscribable,

pub fn new( config: RuntimeConfig, factory: fn() -> FilterFactory, cb: impl Fn(S) + 'a, ) -> Result<Self>

Creates a new runtime from the config settings, filter, and callback.

Remarks

The factory parameter is a macro-generated function pointer based on the user-defined filter string, and must take the value “filter”. cb is the name of the user-defined callback function.

Example
let mut runtime = Runtime::new(config, filter, callback)?;
pub fn run(&mut self)

Run Retina for the duration specified in the configuration or until ctrl-c to terminate.

Example
runtime.run();